@@ -481,7 +481,7 @@ class CFG:
 
         print(tabulate(data, tablefmt="fancy_grid"))
 
-    def accept(self, tokens: List[Token], debug=False):
+    def accept(self, tokens: List[Token], debug=False, transform=True):
         """Validates a sequence of tokens using the LL(1) parser. This wrapper already
         calculate First and Follow sets, eliminates left recursion and apply left factoring
         to remove non-determinism to the grammar.
@@ -489,6 +489,7 @@ class CFG:
         Args:
             tokens (List[Token]): List of tokens to be validated
             debug (bool, optional): Debug level flag. Defaults to False.
+            debug (bool, optional): Transform base grammar to LL1. Defaults to False.
 
         Raises:
             SyntaxException: if a syntax error is found
@@ -498,8 +499,10 @@ class CFG:
         """
         self.calculate_first()
         self.calculate_follow()
-        self.eliminate_left_recursion()
-        self.left_factoring()
+
+        if transform:
+            self.eliminate_left_recursion()
+            self.left_factoring()
 
         table = self.table()
 
@@ -529,7 +532,7 @@ class CFG:
                 stack.pop()
 
                 continue
-
+            
             if symbol not in table[stack[-1]]:
                 if symbol == "$":
                     raise SyntaxException(f"Unexpected EOL: {sentence[i - 1]}")
